@@ -1,15 +1,16 @@
-/* constants.h -- This file is part of Archimedes release 0.0.7.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
+/* constants.h -- This file is part of Archimedes release 1.1.0.
+   Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements both the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
-   electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+   electrons and holes. It includes some quantum effects by means 
+   of effective potential method. It is also able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004-2011 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -18,14 +19,13 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 // ######################################################
 // Created on 5 aug.2004, Siracusa, J.M.Sellier
-// Last modif. : 27 dec.2006, Siracusa, J.M.Sellier
+// Last modif. : 17 aug.2011, Carry le Rouet, France, J.M.Sellier
 // ######################################################
 
 // Universal Physical Constants in M.K.S.C. system
@@ -49,12 +49,6 @@
  const real PI=3.141592654;
 // electron energy step (eV) for the MC method
  const real DE=0.002;
-// mstar coefficient for Si heavy hole
- const real mstarHSILICON=0.57;
-// mstar coefficient for Germanium heavy hole
- const real mstarHGERMANIUM=0.73;
-// mstar coefficient for GaAs heavy hole
- const real mstarHGAAS=0.510;
 // Silicon low field mobility (m^2/(V*sec))
  real MIU0=1400.e-4;
 // Silicon saturation velocity (m/sec)
